@@ -33,8 +33,8 @@ def parse_arguments():
                         required=True)
     parser.add_argument('-o', '--output_path', type=str, default='processed',
                         help="Folder path to save the outputs")
-    parser.add_argument('-n', '--number_of_parents', type=int,
-                        default=0, help='Number of parents to recursively group Allen area.')
+    parser.add_argument('-n', '--number_of_parents', type=int, choices=range(8),
+                        default=0, help='Number of parents to recursively group Allen area, valid numbers are integers in [0, 7].')
 
     return parser.parse_args()
 
@@ -103,6 +103,7 @@ def get_mapping(labels, n):
     n_not_found = 0
     area_unknown = {}
     for l in labels:
+        # Fetch the ancestor map of the label.
         try:
             ids = ancestor_map[int(l)]
         except KeyError:
@@ -117,12 +118,16 @@ def get_mapping(labels, n):
                 area_unknown[int(l)] += 1
             continue
 
-        if len(ids) <= 2:
+        # At the bottom of the tree each regions has 10 ancestors, with 'root' being the higher
+        n_ancestors = len(ids)
+        n_start = 10 - n_ancestors
+        if n <= n_start:
             id = ids[0]
-        elif len(ids) <= n:
-            id = ids[-2]
-        else:
-            id = ids[n if n < len(ids) - 1 else n - 1]
+        elif n > n_start:
+            if n_ancestors > n - n_start + 1:
+                id = ids[n-n_start]
+            else:
+                id = ids[-2]
 
         # Get the name and store it
         name = name_map[id]
